@@ -7,8 +7,8 @@ import yaml
 
 __oms = {
     "name"        : "OpenManuscript",
-    "toolversion" : "3.5.2",
-    "specversion" : "2.0"
+    "toolversion" : "3.6.1",
+    "specversion" : "2.1"
 }
 
 settings = {
@@ -28,6 +28,9 @@ settings = {
     "manuscripttype"  : "novel",
     "notes"           : False,
     "outputfile"      : "manuscript.docx",
+    "slug"            : None,
+    "todo"            : None,
+    "notitlepage"     : False,
     "toc"             : False
 }
 
@@ -37,6 +40,8 @@ author = {
 manuscript = {
 }
 
+postamble = "Fin."
+
 # ---------------------------------------------------------------------------
 #
 # given a json file, set core settings from key, value pairs 
@@ -321,8 +326,9 @@ def get_scenelist():
 
     scenelist = []
     for chapter in manuscript["chapters"]:
-        for scene in chapter["scenes"]:
-            scenelist.append(scene)
+        if "scenes" in chapter:
+            for scene in chapter["scenes"]:
+                scenelist.append(scene)
 
     newlist = []
     for i in scenelist:
@@ -340,7 +346,8 @@ def find_tagged_scenes():
 
     for chapter in manuscript["chapters"]:
         if check_chapter_tags( chapter ):
-            scenes.extend(chapter["scenes"])
+            if "scenes" in chapter:
+                scenes.extend(chapter["scenes"])
 
     return scenes
 
