@@ -50,7 +50,7 @@ def create_attribute(element, name, value):
     element.set(qn(name), value)
 
 # set the starting page number of a section
-def set_start_page_number(section, number=0, fmt='decimal'):
+def set_start_page_number(section, number=1, fmt='decimal'):
     pagenum  = create_element('w:pgNumType')
     create_attribute(pagenum, 'w:start', str(number).encode("utf-8"))
     create_attribute(pagenum, 'w:fmt', fmt) 
@@ -75,7 +75,7 @@ def add_page_number(run):
 #
 
 def write_toc( doc, ms ):
-    doc.add_page_break()
+    # doc.add_page_break()
     add_toc_section(doc, WD_SECTION.CONTINUOUS)
 
     # spacing from top of page 
@@ -135,6 +135,10 @@ def write_toc( doc, ms ):
             else:
                 run = p.add_run("{}: \t{}".format(allcaps_title, chaptername))
 
+    # end the TOC
+    doc.add_page_break()
+    
+
 def add_to_run(run, text):
     fldChar1 = create_element('w:fldChar')
     create_attribute(fldChar1, 'w:fldCharType', 'begin')
@@ -241,6 +245,17 @@ def write_title(document):
     pf.line_spacing_rule = WD_LINE_SPACING.DOUBLE
     run = p.add_run("{}".format(core.author["name"]))
 
+    # slug 
+    if (core.settings["slug"] != None) and (core.settings["slug"] != "None"):
+        p = document.add_paragraph()
+        pf = p.paragraph_format
+        pf.alignment = WD_ALIGN_PARAGRAPH.CENTER
+        pf.line_spacing_rule = WD_LINE_SPACING.DOUBLE
+        run = p.add_run("({})".format(core.settings["slug"]))
+
+    # end the page
+    document.add_page_break()
+
 
 def write_paragraph_space(document):
     p = document.add_paragraph()
@@ -266,7 +281,7 @@ def write_chapter_heading(document, chapter, chapnum, chaptype):
         increment_chapter = False
 
     # add half a page of spacing
-    document.add_page_break()
+    # document.add_page_break()
     for i in range(0, 10):
         p = document.add_paragraph()
         pf = p.paragraph_format
@@ -340,7 +355,17 @@ def write_preamble(doc):
     style.paragraph_format.line_spacing_rule = WD_LINE_SPACING.DOUBLE
 
 def write_postamble(doc):
-    # print("WORD: write_postamble (no-op)")
+    # spacing to title
+    for i in range(15):
+        doc.add_paragraph()
+
+    # add text
+    p = doc.add_paragraph()
+    pf = p.paragraph_format
+    pf.alignment = WD_ALIGN_PARAGRAPH.CENTER
+    pf.line_spacing_rule = WD_LINE_SPACING.DOUBLE
+    run = p.add_run("{}".format(core.postamble))
+
     return
 
 def write_docinfo(doc):
@@ -378,6 +403,15 @@ def handle_include( data ):
 
     return data
 
+# -----------------------------------------------------------------------------
+# substitute emdash 
+# -----------------------------------------------------------------------------
+def handle_emdash( data ):
+    subflags = flags=re.MULTILINE|re.DOTALL
+    data  = re.sub(rf'--', u'\u2014', data, flags=subflags)
+
+    return data
+
 
 # -----------------------------------------------------------------------------
 # handle arbitrary html syntax tag 
@@ -473,6 +507,7 @@ def create_scene_text(scenetext):
 
     scenetext = handle_include(scenetext)
     scenetext = handle_notes(scenetext, core.settings["notes"])
+    scenetext = handle_emdash(scenetext)
 
     html_tree = None
     if scenetext:
@@ -531,6 +566,9 @@ def write_chapter(doc, chapter, chapnum):
             if not scene.endswith(".pdf"):
                 write_scenefile(doc, scene)
 
+    # end the chapter
+    doc.add_page_break()
+
     return increment_chapter
 
 def write_chapters(doc, manuscript):
@@ -565,7 +603,8 @@ def write(outputfile):
         write_preamble(theDocument)
         write_docinfo(theDocument)
         # write_headers(theDocument)
-        write_title(theDocument)
+        if not core.settings["notitlepage"]:
+            write_title(theDocument)
         if core.settings["toc"]:
             write_toc(theDocument, core.manuscript)
         # debug_sections(theDocument)
